/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's fiscal year    *
* 2002 Organizational file and create a SAS dataset.                                     *
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer, replacing the '.' with the *
* folder path location (e.g. 'C:\temp') .                                                *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located, replacing the '.' with the folder   *
* path location (e.g. 'C:\temp') .                                                       *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\corp02nid.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = corp02nid ;

DATA library.&dataset ;
INFILE datafile LRECL=3404;
INPUT
   DISGORGE  1-3            CPIDN  4-7               AMENDYR  8-11         
   BUSTEXT $ 12-40          OWNSTEXT $ 41            FINSTXT $ 42-100      
   FINDOTXT $ 101           OFENTXT1 $ 102-132       OFENTXT2 $ 133        
   OFENTXT3 $ 134           PRMONTXT $ 135-233       ORDERTXT $ 234-333    
   REASTXT1 $ 334-347       REASTXT2 $ 348           REASTXT3 $ 349        
   REASTXT4 $ 350           OUTSOURC $ 351-379       PSR  380              
   JANDC  381               PLEA  382                REASONS  383          
   INDICT  384              SENTRANS  385            WRKSHT  386           
   INCORPYR  387-390        INCORLOC  391            ORGTYPE  392          
   BUSCLAS  393-396         FTEMNUM  397-401         FTEMSIGN  402         
   SELFREP  403             HSMISCND  404            PRCRIME  405          
   PRCIVIL  406             OWNSTRCT  407            FINSTDS  408          
   FINSTDO  409             PRIMOFF  410-411         NOCOUNTS  412-413     
   SOURCES  414             OFFLVL  415-416          DETBFINE  417         
   TOLERNCE  418            HISTORY  419             VIOLATE  420          
   OBSTRUCT  421            COMPLY  422              ACCEPT  423-424       
   CCULPSCO  425            FCULPSCO  426-427        MINFINML  428-430     
   MAXFINML  431-433        DISPOSIT  434            PROBATN  435-436      
   COFI  437                PROBMON  438             ORDERCE  439          
   TYPEOTHS  440-441        CRIMPURP  442            CANTPAY  443          
   DEPSOR  444              REASON1  445-447         REASON2  448          
   REASON3  449             REASON4  450             NOCOMP  451           
   ADJR_B1  452-453         ADJR_B2  454-455         ADJR_B3  456          
   ADJR_B4  457             ADJR_B5  458             ADJR_C1  459          
   ADJR_C2  460             ADJR_C3  461             ADJR_C4  462          
   ADJR_C5  463             ADJR_D1  464             ADJR_D2  465          
   ADJR_D3  466             ADJR_D4  467             ADJR_D5  468          
   ADJR_E1  469             ADJR_E2  470             ADJR_E3  471          
   ADJR_E4  472             ADJR_E5  473             ADJR_F1  474          
   ADJR_F2  475             ADJR_F3  476             ADJR_F4  477          
   ADJR_F5  478             ADJR_G1  479             ADJR_G2  480          
   ADJR_G3  481             ADJR_G4  482             ADJR_G5  483          
   ADJR_H1  484             ADJR_H2  485             ADJR_H3  486          
   ADJR_H4  487             ADJR_H5  488             ADJR_I1  489          
   ADJR_I2  490             ADJR_I3  491             ADJR_I4  492          
   ADJR_I5  493             ADJR_J1  494             ADJR_J2  495          
   ADJR_J3  496             ADJR_J4  497             ADJR_J5  498          
   ADJR_K1  499             ADJR_K2  500             ADJR_K3  501          
   ADJR_K4  502             ADJR_K5  503             ADJR_L1  504          
   ADJR_L2  505             ADJR_L3  506             ADJR_L4  507          
   ADJR_L5  508             ADJR_M1  509             ADJR_M2  510          
   ADJR_M3  511             ADJR_M4  512             ADJR_M5  513          
   ADJR_N1  514             ADJR_N2  515             ADJR_N3  516          
   ADJR_N4  517             ADJR_N5  518             ADJR_O1  519          
   ADJR_O2  520             ADJR_O3  521             ADJR_O4  522          
   ADJR_O5  523             ADJR_P1  524             ADJR_P2  525          
   ADJR_P3  526             ADJR_P4  527             ADJR_P5  528          
   ADJ_B1  529-530          ADJ_B2  531-532          ADJ_B3  533           
   ADJ_B4  534              ADJ_B5  535              ADJ_C1  536-538       
   ADJ_C2  539              ADJ_C3  540              ADJ_C4  541           
   ADJ_C5  542              ADJ_D1  543              ADJ_D2  544           
   ADJ_D3  545              ADJ_D4  546              ADJ_D5  547           
   ADJ_E1  548              ADJ_E2  549              ADJ_E3  550           
   ADJ_E4  551              ADJ_E5  552              ADJ_F1  553           
   ADJ_F2  554              ADJ_F3  555              ADJ_F4  556           
   ADJ_F5  557              ADJ_G1  558              ADJ_G2  559           
   ADJ_G3  560              ADJ_G4  561              ADJ_G5  562           
   ADJ_H1  563              ADJ_H2  564              ADJ_H3  565           
   ADJ_H4  566              ADJ_H5  567              ADJ_I1  568           
   ADJ_I2  569              ADJ_I3  570              ADJ_I4  571           
   ADJ_I5  572              ADJ_J1  573              ADJ_J2  574           
   ADJ_J3  575              ADJ_J4  576              ADJ_J5  577           
   ADJ_K1  578              ADJ_K2  579              ADJ_K3  580           
   ADJ_K4  581              ADJ_K5  582              ADJ_L1  583           
   ADJ_L2  584              ADJ_L3  585              ADJ_L4  586           
   ADJ_L5  587              ADJ_M1  588              ADJ_M2  589           
   ADJ_M3  590              ADJ_M4  591              ADJ_M5  592           
   ADJ_N1  593              ADJ_N2  594              ADJ_N3  595           
   ADJ_N4  596              ADJ_N5  597              ADJ_O1  598           
   ADJ_O2  599              ADJ_O3  600              ADJ_O4  601           
   ADJ_O5  602              ADJ_P1  603              ADJ_P2  604           
   ADJ_P3  605              ADJ_P4  606              ADJ_P5  607           
   BASADJ1  608             BASADJ2  609             BASADJ3  610          
   BASADJ4  611             BASADJ5  612             BASADR1  613          
   BASADR2  614             BASADR3  615             BASADR4  616          
   BASADR5  617             BASE1  618-619           BASE2  620-621        
   BASE3  622-623           BASE4  624-625           BASE5  626-627        
   BASER1  628-629          BASER2  630-631          BASER3  632-633       
   BASER4  634-635          BASER5  636-637          GDLINE1 $ 638-642     
   GDLINE2 $ 643-648        GDLINE3 $ 649-653        GDLINE4 $ 654-658     
   GDLINE5 $ 659-663        GDREF1 $ 664-668         GDREF2 $ 669-673      
   GDREF3 $ 674-678         GDREF4 $ 679-683         GDREF5 $ 684-688      
   GDSTAT1 $ 689-693        GDSTAT2 $ 694-699        GDSTAT3 $ 700-704     
   GDSTAT4 $ 705-709        GDSTAT5 $ 710-714        ADJOFL1  715-716      
   ADJOFL2  717-718         ADJOFL3  719-720         ADJOFL4  721-722      
   ADJOFL5  723-724         ADJOFR1  725-726         ADJOFR2  727-728      
   ADJOFR3  729-730         ADJOFR4  731-732         ADJOFR5  733-734      
   GDSTATHI $ 735-739       GDLINEHI $ 740-744       ADJOFLHI  745-746     
   BASEHI  747-748          ADJ_BHI  749-750         ADJ_CHI  751-753      
   ADJ_DHI  754             ADJ_EHI  755             ADJ_FHI  756          
   ADJ_GHI  757             ADJ_HHI  758             ADJ_IHI  759          
   ADJ_JHI  760             ADJ_KHI  761             ADJ_LHI  762          
   ADJ_MHI  763             ADJ_NHI  764             ADJ_OHI  765          
   ADJ_PHI  766             BASADJHI  767            GDREFHI $ 768-772     
   BASERHI  773-774         ADJR_BHI  775-776        ADJR_CHI  777         
   ADJR_DHI  778            ADJR_EHI  779            ADJR_FHI  780         
   ADJR_GHI  781            ADJR_HHI  782            ADJR_IHI  783         
   ADJR_JHI  784            ADJR_KHI  785            ADJR_LHI  786         
   ADJR_MHI  787            ADJR_NHI  788            ADJR_OHI  789         
   ADJR_PHI  790            BASADRHI  791            ADJOFRHI  792-793     
   SMIN1  794-797           SMIN2  798               SMIN3  799            
   SMIN4  800               SMIN5  801               SMIN6  802            
   SMIN7  803               SMIN8  804               SMIN9  805            
   SMIN10  806              SMIN11  807              SMIN12  808           
   SMIN13  809              SMIN14  810              SMIN15  811           
   SMIN16  812              SMIN17  813              SMIN18  814           
   SMIN19  815              SMIN20  816              SMIN21  817           
   SMIN22  818              SMIN23  819              SMIN24  820           
   SMIN25  821              SMIN26  822              SMIN27  823           
   SMIN28  824              SMIN29  825              SMIN30  826           
   SMIN31  827              SMIN32  828              SMIN33  829           
   SMIN34  830              SMIN35  831              SMIN36  832           
   SMIN37  833              SMIN38  834              SMIN39  835           
   SMIN40  836              SMIN41  837              SMIN42  838           
   SMIN43  839              SMIN44  840              SMIN45  841           
   SMIN46  842              SMIN47  843              SMIN48  844           
   SMIN49  845              SMIN50  846              SMIN51  847           
   SMIN52  848              SMIN53  849              SMIN54  850           
   SMIN55  851              SMIN56  852              SMIN57  853           
   SMIN58  854              SMIN59  855              SMIN60  856           
   SMIN61  857              SMIN62  858              SMIN63  859           
   SMIN64  860              SMIN65  861              SMIN66  862           
   SMIN67  863              SMIN68  864              SMIN69  865           
   SMIN70  866              SMIN71  867              SMIN72  868           
   SMIN73  869              SMIN74  870              SMIN75  871           
   SMIN76  872              SMIN77  873              SMIN78  874           
   SMIN79  875              SMIN80  876              SMIN81  877           
   SMIN82  878              SMAX1  879-886           SMAX2  887-894        
   SMAX3  895-901           SMAX4  902-908           SMAX5  909-915        
   SMAX6  916-921           SMAX7  922-927           SMAX8  928-933        
   SMAX9  934-939           SMAX10  940-945          SMAX11  946-951       
   SMAX12  952-957          SMAX13  958-963          SMAX14  964-969       
   SMAX15  970-975          SMAX16  976-981          SMAX17  982-987       
   SMAX18  988-993          SMAX19  994-999          SMAX20  1000-1005     
   SMAX21  1006-1011        SMAX22  1012-1017        SMAX23  1018-1023     
   SMAX24  1024-1029        SMAX25  1030-1035        SMAX26  1036-1041     
   SMAX27  1042-1047        SMAX28  1048-1053        SMAX29  1054-1059     
   SMAX30  1060-1065        SMAX31  1066-1071        SMAX32  1072-1077     
   SMAX33  1078-1083        SMAX34  1084-1089        SMAX35  1090-1095     
   SMAX36  1096-1101        SMAX37  1102-1107        SMAX38  1108-1113     
   SMAX39  1114-1119        SMAX40  1120-1125        SMAX41  1126-1131     
   SMAX42  1132-1137        SMAX43  1138-1143        SMAX44  1144-1149     
   SMAX45  1150-1155        SMAX46  1156-1161        SMAX47  1162-1167     
   SMAX48  1168-1173        SMAX49  1174-1179        SMAX50  1180-1185     
   SMAX51  1186-1191        SMAX52  1192-1197        SMAX53  1198-1203     
   SMAX54  1204-1209        SMAX55  1210-1215        SMAX56  1216-1221     
   SMAX57  1222-1227        SMAX58  1228-1233        SMAX59  1234-1239     
   SMAX60  1240-1245        SMAX61  1246-1251        SMAX62  1252-1257     
   SMAX63  1258-1263        SMAX64  1264-1269        SMAX65  1270-1275     
   SMAX66  1276-1281        SMAX67  1282-1287        SMAX68  1288-1293     
   SMAX69  1294-1299        SMAX70  1300-1305        SMAX71  1306-1311     
   SMAX72  1312-1317        SMAX73  1318-1323        SMAX74  1324-1329     
   SMAX75  1330-1335        SMAX76  1336-1341        SMAX77  1342-1347     
   SMAX78  1348-1353        SMAX79  1354-1359        SMAX80  1360-1365     
   SMAX81  1366-1371        SMAX82  1372-1377        STA1_1 $ 1378-1387    
   STA1_2 $ 1388-1396       STA1_3 $ 1397-1405       STA1_4 $ 1406-1414    
   STA1_5 $ 1415-1423       STA1_6 $ 1424-1432       STA1_7 $ 1433-1441    
   STA1_8 $ 1442-1450       STA1_9 $ 1451-1459       STA1_10 $ 1460-1468   
   STA1_11 $ 1469-1477      STA1_12 $ 1478-1483      STA1_13 $ 1484-1489   
   STA1_14 $ 1490-1495      STA1_15 $ 1496-1501      STA1_16 $ 1502-1507   
   STA1_17 $ 1508-1513      STA1_18 $ 1514-1519      STA1_19 $ 1520-1525   
   STA1_20 $ 1526-1531      STA1_21 $ 1532-1537      STA1_22 $ 1538-1543   
   STA1_23 $ 1544-1553      STA1_24 $ 1554-1563      STA1_25 $ 1564-1573   
   STA1_26 $ 1574-1583      STA1_27 $ 1584-1593      STA1_28 $ 1594-1603   
   STA1_29 $ 1604-1613      STA1_30 $ 1614-1623      STA1_31 $ 1624-1633   
   STA1_32 $ 1634-1643      STA1_33 $ 1644-1653      STA1_34 $ 1654-1663   
   STA1_35 $ 1664-1673      STA1_36 $ 1674-1683      STA1_37 $ 1684-1693   
   STA1_38 $ 1694-1703      STA1_39 $ 1704-1706      STA1_40 $ 1707-1709   
   STA1_41 $ 1710-1712      STA1_42 $ 1713-1715      STA1_43 $ 1716-1718   
   STA1_44 $ 1719-1721      STA1_45 $ 1722-1724      STA1_46 $ 1725-1727   
   STA1_47 $ 1728-1730      STA1_48 $ 1731-1733      STA1_49 $ 1734-1736   
   STA1_50 $ 1737-1739      STA1_51 $ 1740-1742      STA1_52 $ 1743-1745   
   STA1_53 $ 1746-1748      STA1_54 $ 1749-1751      STA1_55 $ 1752-1754   
   STA1_56 $ 1755-1757      STA1_57 $ 1758-1760      STA1_58 $ 1761-1763   
   STA1_59 $ 1764-1766      STA1_60 $ 1767-1769      STA1_61 $ 1770-1772   
   STA1_62 $ 1773-1775      STA1_63 $ 1776-1778      STA1_64 $ 1779-1781   
   STA1_65 $ 1782-1784      STA1_66 $ 1785-1787      STA1_67 $ 1788-1790   
   STA1_68 $ 1791-1793      STA1_69 $ 1794-1796      STA1_70 $ 1797-1799   
   STA1_71 $ 1800-1802      STA1_72 $ 1803-1805      STA1_73 $ 1806-1808   
   STA1_74 $ 1809-1811      STA1_75 $ 1812-1814      STA1_76 $ 1815-1817   
   STA1_77 $ 1818-1820      STA1_78 $ 1821-1823      STA1_79 $ 1824-1826   
   STA1_80 $ 1827-1829      STA1_81 $ 1830-1832      STA1_82 $ 1833-1835   
   STA2_1 $ 1836-1846       STA2_2 $ 1847-1857       STA2_3 $ 1858-1868    
   STA2_4 $ 1869-1878       STA2_5 $ 1879-1888       STA2_6 $ 1889-1898    
   STA2_7 $ 1899-1908       STA2_8 $ 1909-1918       STA2_9 $ 1919-1928    
   STA2_10 $ 1929-1938      STA2_11 $ 1939-1948      STA2_12 $ 1949-1958   
   STA2_13 $ 1959-1968      STA2_14 $ 1969-1978      STA2_15 $ 1979-1988   
   STA2_16 $ 1989-1998      STA2_17 $ 1999-2008      STA2_18 $ 2009-2018   
   STA2_19 $ 2019-2028      STA2_20 $ 2029-2038      STA2_21 $ 2039-2048   
   STA2_22 $ 2049-2058      STA2_23 $ 2059-2068      STA2_24 $ 2069-2078   
   STA2_25 $ 2079-2088      STA2_26 $ 2089-2098      STA2_27 $ 2099-2108   
   STA2_28 $ 2109-2118      STA2_29 $ 2119-2128      STA2_30 $ 2129-2138   
   STA2_31 $ 2139-2148      STA2_32 $ 2149-2158      STA2_33 $ 2159-2168   
   STA2_34 $ 2169-2178      STA2_35 $ 2179-2188      STA2_36 $ 2189-2197   
   STA2_37 $ 2198-2206      STA2_38 $ 2207-2215      STA2_39 $ 2216-2224   
   STA2_40 $ 2225-2233      STA2_41 $ 2234-2242      STA2_42 $ 2243-2251   
   STA2_43 $ 2252-2259      STA2_44 $ 2260-2267      STA2_45 $ 2268-2275   
   STA2_46 $ 2276-2283      STA2_47 $ 2284-2291      STA2_48 $ 2292-2299   
   STA2_49 $ 2300-2307      STA2_50 $ 2308-2315      STA2_51 $ 2316-2323   
   STA2_52 $ 2324-2331      STA2_53 $ 2332-2339      STA2_54 $ 2340-2347   
   STA2_55 $ 2348-2355      STA2_56 $ 2356-2363      STA2_57 $ 2364-2371   
   STA2_58 $ 2372-2379      STA2_59 $ 2380-2387      STA2_60 $ 2388-2395   
   STA2_61 $ 2396-2403      STA2_62 $ 2404-2411      STA2_63 $ 2412-2419   
   STA2_64 $ 2420-2427      STA2_65 $ 2428-2435      STA2_66 $ 2436-2443   
   STA2_67 $ 2444-2451      STA2_68 $ 2452-2459      STA2_69 $ 2460-2467   
   STA2_70 $ 2468-2475      STA2_71 $ 2476-2483      STA2_72 $ 2484-2491   
   STA2_73 $ 2492-2499      STA2_74 $ 2500-2507      STA2_75 $ 2508-2515   
   STA2_76 $ 2516-2523      STA2_77 $ 2524-2531      STA2_78 $ 2532-2539   
   STA2_79 $ 2540-2547      STA2_80 $ 2548-2555      STA2_81 $ 2556-2563   
   STA2_82 $ 2564-2571      STA3_1 $ 2572-2580       STA3_2 $ 2581-2589    
   STA3_3 $ 2590-2600       STA3_4 $ 2601-2611       STA3_5 $ 2612-2622    
   STA3_6 $ 2623-2633       STA3_7 $ 2634-2644       STA3_8 $ 2645-2655    
   STA3_9 $ 2656-2666       STA3_10 $ 2667-2677      STA3_11 $ 2678-2688   
   STA3_12 $ 2689-2699      STA3_13 $ 2700-2710      STA3_14 $ 2711-2721   
   STA3_15 $ 2722-2732      STA3_16 $ 2733-2743      STA3_17 $ 2744-2754   
   STA3_18 $ 2755-2765      STA3_19 $ 2766-2776      STA3_20 $ 2777-2787   
   STA3_21 $ 2788-2798      STA3_22 $ 2799-2809      STA3_23 $ 2810-2820   
   STA3_24 $ 2821-2831      STA3_25 $ 2832-2842      STA3_26 $ 2843-2853   
   STA3_27 $ 2854-2864      STA3_28 $ 2865-2875      STA3_29 $ 2876-2886   
   STA3_30 $ 2887-2897      STA3_31 $ 2898-2908      STA3_32 $ 2909-2919   
   STA3_33 $ 2920-2930      STA3_34 $ 2931-2941      STA3_35 $ 2942-2952   
   STA3_36 $ 2953-2959      STA3_37 $ 2960-2966      STA3_38 $ 2967-2973   
   STA3_39 $ 2974-2980      STA3_40 $ 2981-2987      STA3_41 $ 2988-2994   
   STA3_42 $ 2995-3001      STA3_43 $ 3002           STA3_44 $ 3003        
   STA3_45 $ 3004           STA3_46 $ 3005           STA3_47 $ 3006        
   STA3_48 $ 3007           STA3_49 $ 3008           STA3_50 $ 3009        
   STA3_51 $ 3010           STA3_52 $ 3011           STA3_53 $ 3012        
   STA3_54 $ 3013           STA3_55 $ 3014           STA3_56 $ 3015        
   STA3_57 $ 3016           STA3_58 $ 3017           STA3_59 $ 3018        
   STA3_60 $ 3019           STA3_61 $ 3020           STA3_62 $ 3021        
   STA3_63 $ 3022           STA3_64 $ 3023           STA3_65 $ 3024        
   STA3_66 $ 3025           STA3_67 $ 3026           STA3_68 $ 3027        
   STA3_69 $ 3028           STA3_70 $ 3029           STA3_71 $ 3030        
   STA3_72 $ 3031           STA3_73 $ 3032           STA3_74 $ 3033        
   STA3_75 $ 3034           STA3_76 $ 3035           STA3_77 $ 3036        
   STA3_78 $ 3037           STA3_79 $ 3038           STA3_80 $ 3039        
   STA3_81 $ 3040           STA3_82 $ 3041           NWSTAT1 $ 3042-3051   
   NWSTAT2 $ 3052-3062      NWSTAT3 $ 3063-3073      NWSTAT4 $ 3074-3083   
   NWSTAT5 $ 3084-3093      NWSTAT6 $ 3094-3102      NWSTAT7 $ 3103-3111   
   NWSTAT8 $ 3112-3122      NWSTAT9 $ 3123-3129      NOUSTAT  3130         
   BASEFINE  3131-3139      CH2APP  3140             CH8FINGD  3141        
   CMSRVORD  3142           COMPLYPR  3143           COSTASSM  3144        
   FINOFFST  3145-3150      FORFEITR  3151-3158      GLFINMAX  3159-3167   
   GLFINMIN  3168-3176      OFFENSE1  3177-3178      OFFENSE2  3179-3180   
   OFFENSE3  3181           REMEDORD  3182-3184      VICTNOTE  3185        
   QUARTER  3186            SENTYR  3187-3190        TYPEOTTX $ 3191-3387  
   NEWCNVTN  3388           NOREAS  3389             RESTCAT  3390         
   FINECAT  3391            SUSFNCAT  3392           LCAT1  3393           
   LCAT2  3394              LCAT3  3395              LCAT4  3396           
   LCAT5  3397              LCATHI  3398             LCATR1  3399          
   LCATR2  3400             LCATR3  3401             LCATR4  3402          
   LCATR5  3403             LCATRHI  3404          ;                       

LENGTH
   DISGORGE 4               CPIDN 4                  AMENDYR 4             
   PSR 3                    JANDC 3                  PLEA 3                
   REASONS 3                INDICT 3                 SENTRANS 3            
   WRKSHT 3                 INCORPYR 4               INCORLOC 3            
   ORGTYPE 3                BUSCLAS 4                FTEMNUM 6             
   FTEMSIGN 3               SELFREP 3                HSMISCND 3            
   PRCRIME 3                PRCIVIL 3                OWNSTRCT 3            
   FINSTDS 3                FINSTDO 3                PRIMOFF 3             
   NOCOUNTS 3               SOURCES 3                OFFLVL 3              
   DETBFINE 3               TOLERNCE 3               HISTORY 3             
   VIOLATE 3                OBSTRUCT 3               COMPLY 3              
   ACCEPT 3                 CCULPSCO 3               FCULPSCO 3            
   DISPOSIT 3               PROBATN 3                COFI 3                
   PROBMON 3                ORDERCE 3                TYPEOTHS 3            
   CRIMPURP 3               CANTPAY 3                DEPSOR 3              
   REASON1 4                REASON2 3                REASON3 3             
   REASON4 3                NOCOMP 3                 ADJR_B1 3             
   ADJR_B2 3                ADJR_B3 3                ADJR_B4 3             
   ADJR_B5 3                ADJR_C1 3                ADJR_C2 3             
   ADJR_C3 3                ADJR_C4 3                ADJR_C5 3             
   ADJR_D1 3                ADJR_D2 3                ADJR_D3 3             
   ADJR_D4 3                ADJR_D5 3                ADJR_E1 3             
   ADJR_E2 3                ADJR_E3 3                ADJR_E4 3             
   ADJR_E5 3                ADJR_F1 3                ADJR_F2 3             
   ADJR_F3 3                ADJR_F4 3                ADJR_F5 3             
   ADJR_G1 3                ADJR_G2 3                ADJR_G3 3             
   ADJR_G4 3                ADJR_G5 3                ADJR_H1 3             
   ADJR_H2 3                ADJR_H3 3                ADJR_H4 3             
   ADJR_H5 3                ADJR_I1 3                ADJR_I2 3             
   ADJR_I3 3                ADJR_I4 3                ADJR_I5 3             
   ADJR_J1 3                ADJR_J2 3                ADJR_J3 3             
   ADJR_J4 3                ADJR_J5 3                ADJR_K1 3             
   ADJR_K2 3                ADJR_K3 3                ADJR_K4 3             
   ADJR_K5 3                ADJR_L1 3                ADJR_L2 3             
   ADJR_L3 3                ADJR_L4 3                ADJR_L5 3             
   ADJR_M1 3                ADJR_M2 3                ADJR_M3 3             
   ADJR_M4 3                ADJR_M5 3                ADJR_N1 3             
   ADJR_N2 3                ADJR_N3 3                ADJR_N4 3             
   ADJR_N5 3                ADJR_O1 3                ADJR_O2 3             
   ADJR_O3 3                ADJR_O4 3                ADJR_O5 3             
   ADJR_P1 3                ADJR_P2 3                ADJR_P3 3             
   ADJR_P4 3                ADJR_P5 3                ADJ_B1 3              
   ADJ_B2 3                 ADJ_B3 3                 ADJ_B4 3              
   ADJ_B5 3                 ADJ_C1 3                 ADJ_C2 3              
   ADJ_C3 3                 ADJ_C4 3                 ADJ_C5 3              
   ADJ_D1 3                 ADJ_D2 3                 ADJ_D3 3              
   ADJ_D4 3                 ADJ_D5 3                 ADJ_E1 3              
   ADJ_E2 3                 ADJ_E3 3                 ADJ_E4 3              
   ADJ_E5 3                 ADJ_F1 3                 ADJ_F2 3              
   ADJ_F3 3                 ADJ_F4 3                 ADJ_F5 3              
   ADJ_G1 3                 ADJ_G2 3                 ADJ_G3 3              
   ADJ_G4 3                 ADJ_G5 3                 ADJ_H1 3              
   ADJ_H2 3                 ADJ_H3 3                 ADJ_H4 3              
   ADJ_H5 3                 ADJ_I1 3                 ADJ_I2 3              
   ADJ_I3 3                 ADJ_I4 3                 ADJ_I5 3              
   ADJ_J1 3                 ADJ_J2 3                 ADJ_J3 3              
   ADJ_J4 3                 ADJ_J5 3                 ADJ_K1 3              
   ADJ_K2 3                 ADJ_K3 3                 ADJ_K4 3              
   ADJ_K5 3                 ADJ_L1 3                 ADJ_L2 3              
   ADJ_L3 3                 ADJ_L4 3                 ADJ_L5 3              
   ADJ_M1 3                 ADJ_M2 3                 ADJ_M3 3              
   ADJ_M4 3                 ADJ_M5 3                 ADJ_N1 3              
   ADJ_N2 3                 ADJ_N3 3                 ADJ_N4 3              
   ADJ_N5 3                 ADJ_O1 3                 ADJ_O2 3              
   ADJ_O3 3                 ADJ_O4 3                 ADJ_O5 3              
   ADJ_P1 3                 ADJ_P2 3                 ADJ_P3 3              
   ADJ_P4 3                 ADJ_P5 3                 BASADJ1 3             
   BASADJ2 3                BASADJ3 3                BASADJ4 3             
   BASADJ5 3                BASADR1 3                BASADR2 3             
   BASADR3 3                BASADR4 3                BASADR5 3             
   BASE1 3                  BASE2 3                  BASE3 3               
   BASE4 3                  BASE5 3                  BASER1 3              
   BASER2 3                 BASER3 3                 BASER4 3              
   BASER5 3                 ADJOFL1 3                ADJOFL2 3             
   ADJOFL3 3                ADJOFL4 3                ADJOFL5 3             
   ADJOFR1 3                ADJOFR2 3                ADJOFR3 3             
   ADJOFR4 3                ADJOFR5 3                ADJOFLHI 3            
   BASEHI 3                 ADJ_BHI 3                ADJ_CHI 3             
   ADJ_DHI 3                ADJ_EHI 3                ADJ_FHI 3             
   ADJ_GHI 3                ADJ_HHI 3                ADJ_IHI 3             
   ADJ_JHI 3                ADJ_KHI 3                ADJ_LHI 3             
   ADJ_MHI 3                ADJ_NHI 3                ADJ_OHI 3             
   ADJ_PHI 3                BASADJHI 3               BASERHI 3             
   ADJR_BHI 3               ADJR_CHI 3               ADJR_DHI 3            
   ADJR_EHI 3               ADJR_FHI 3               ADJR_GHI 3            
   ADJR_HHI 3               ADJR_IHI 3               ADJR_JHI 3            
   ADJR_KHI 3               ADJR_LHI 3               ADJR_MHI 3            
   ADJR_NHI 3               ADJR_OHI 3               ADJR_PHI 3            
   BASADRHI 3               ADJOFRHI 3               SMIN1 4               
   SMIN2 3                  SMIN3 3                  SMIN4 3               
   SMIN5 3                  SMIN6 3                  SMIN7 3               
   SMIN8 3                  SMIN9 3                  SMIN10 3              
   SMIN11 3                 SMIN12 3                 SMIN13 3              
   SMIN14 3                 SMIN15 3                 SMIN16 3              
   SMIN17 3                 SMIN18 3                 SMIN19 3              
   SMIN20 3                 SMIN21 3                 SMIN22 3              
   SMIN23 3                 SMIN24 3                 SMIN25 3              
   SMIN26 3                 SMIN27 3                 SMIN28 3              
   SMIN29 3                 SMIN30 3                 SMIN31 3              
   SMIN32 3                 SMIN33 3                 SMIN34 3              
   SMIN35 3                 SMIN36 3                 SMIN37 3              
   SMIN38 3                 SMIN39 3                 SMIN40 3              
   SMIN41 3                 SMIN42 3                 SMIN43 3              
   SMIN44 3                 SMIN45 3                 SMIN46 3              
   SMIN47 3                 SMIN48 3                 SMIN49 3              
   SMIN50 3                 SMIN51 3                 SMIN52 3              
   SMIN53 3                 SMIN54 3                 SMIN55 3              
   SMIN56 3                 SMIN57 3                 SMIN58 3              
   SMIN59 3                 SMIN60 3                 SMIN61 3              
   SMIN62 3                 SMIN63 3                 SMIN64 3              
   SMIN65 3                 SMIN66 3                 SMIN67 3              
   SMIN68 3                 SMIN69 3                 SMIN70 3              
   SMIN71 3                 SMIN72 3                 SMIN73 3              
   SMIN74 3                 SMIN75 3                 SMIN76 3              
   SMIN77 3                 SMIN78 3                 SMIN79 3              
   SMIN80 3                 SMIN81 3                 SMIN82 3              
   SMAX1 6                  SMAX2 6                  SMAX3 6               
   SMAX4 6                  SMAX5 6                  SMAX6 6               
   SMAX7 6                  SMAX8 6                  SMAX9 6               
   SMAX10 6                 SMAX11 6                 SMAX12 6              
   SMAX13 6                 SMAX14 6                 SMAX15 6              
   SMAX16 6                 SMAX17 6                 SMAX18 6              
   SMAX19 6                 SMAX20 6                 SMAX21 6              
   SMAX22 6                 SMAX23 6                 SMAX24 6              
   SMAX25 6                 SMAX26 6                 SMAX27 6              
   SMAX28 6                 SMAX29 6                 SMAX30 6              
   SMAX31 6                 SMAX32 6                 SMAX33 6              
   SMAX34 6                 SMAX35 6                 SMAX36 6              
   SMAX37 6                 SMAX38 6                 SMAX39 6              
   SMAX40 6                 SMAX41 6                 SMAX42 6              
   SMAX43 6                 SMAX44 6                 SMAX45 6              
   SMAX46 6                 SMAX47 6                 SMAX48 6              
   SMAX49 6                 SMAX50 6                 SMAX51 6              
   SMAX52 6                 SMAX53 6                 SMAX54 6              
   SMAX55 6                 SMAX56 6                 SMAX57 6              
   SMAX58 6                 SMAX59 6                 SMAX60 6              
   SMAX61 6                 SMAX62 6                 SMAX63 6              
   SMAX64 6                 SMAX65 6                 SMAX66 6              
   SMAX67 6                 SMAX68 6                 SMAX69 6              
   SMAX70 6                 SMAX71 6                 SMAX72 6              
   SMAX73 6                 SMAX74 6                 SMAX75 6              
   SMAX76 6                 SMAX77 6                 SMAX78 6              
   SMAX79 6                 SMAX80 6                 SMAX81 6              
   SMAX82 6                 NOUSTAT 3                BASEFINE 6            
   CH2APP 3                 CH8FINGD 3               CMSRVORD 3            
   COMPLYPR 3               COSTASSM 3               FINOFFST 6            
   FORFEITR 6               GLFINMAX 6               GLFINMIN 6            
   OFFENSE1 3               OFFENSE2 3               OFFENSE3 3            
   REMEDORD 4               VICTNOTE 3               QUARTER 3             
   SENTYR 4                 NEWCNVTN 3               NOREAS 3              
   RESTCAT 3                FINECAT 3                SUSFNCAT 3            
   LCAT1 3                  LCAT2 3                  LCAT3 3               
   LCAT4 3                  LCAT5 3                  LCATHI 3              
   LCATR1 3                 LCATR2 3                 LCATR3 3              
   LCATR4 3                 LCATR5 3                 LCATRHI 3 ;

         

RUN ;
